# benchmarked [![NPM version](https://img.shields.io/npm/v/benchmarked.svg?style=flat)](https://www.npmjs.com/package/benchmarked) [![NPM downloads](https://img.shields.io/npm/dm/benchmarked.svg?style=flat)](https://npmjs.org/package/benchmarked) [![Build Status](https://img.shields.io/travis/jonschlinkert/benchmarked.svg?style=flat)](https://travis-ci.org/jonschlinkert/benchmarked)

Easily generate benchmarks from a glob of files.

## Install

Install with [npm](https://www.npmjs.com/):

```sh
$ npm install benchmarked --save
```

This is an opinionated wrapper for [benchmarked.js](http://benchmarkjs.com/) to make it easier to do benchmarks. Concept is from [remarkable](https://github.com/jonschlinkert/remarkable/tree/master/benchmark)

## Usage

```js
var suite = require('benchmarked')({
  cwd: 'benchmark',              // optionally define a base directory for code and fixtures
  fixtures: 'my-fixtures/*.txt', // path or glob pattern to fixtures
  code: 'my-functions/*.js'      // path or glob pattern to code files
});

// run the benchmarks
suite.run();
```

See the [examples](./example) to get a better understanding of how this works.

## API

### [Benchmarked](index.js#L21)

Create an instance of Benchmarked with the given `options`.

**Params**

* `options` **{Object}**

**Example**

```js
var benchmarks = new Benchmarked();
```

### [.addFixtures](index.js#L240)

Add fixtures to run benchmarks against.

**Params**

* `patterns` **{String|Array}**: Filepaths or glob patterns.
* `options` **{Options}**

**Example**

```js
benchmarks.addFixtures('fixtures/*.txt');
```

### [.addCode](index.js#L256)

Specify the functions to be benchmarked.

**Params**

* `patterns` **{String|Array}**: Filepath(s) or glob patterns.
* `options` **{Options}**

**Example**

```js
benchmarks.addCode('fixtures/*.txt');
```

### [.addSuite](index.js#L268)

Add benchmark suite to the given `fixture` file.

**Params**

* `fixture` **{Object}**: vinyl file object

### [.run](index.js#L322)

Run the benchmarks.

**Params**

* `options` **{Object}**
* `cb` **{Function}**
* `thisArg` **{Object}**

**Example**

```js
benchmarks.run();
```

## Related projects

You might also be interested in these projects:

* [base-cli](https://www.npmjs.com/package/base-cli): Plugin for base-methods that maps built-in methods to CLI args (also supports methods from a… [more](https://www.npmjs.com/package/base-cli) | [homepage](https://github.com/node-base/base-cli)
* [base-option](https://www.npmjs.com/package/base-option): Adds a few options methods to base, like `option`, `enable` and `disable`. See the readme… [more](https://www.npmjs.com/package/base-option) | [homepage](https://github.com/node-base/base-option)
* [base-pkg](https://www.npmjs.com/package/base-pkg): Plugin for adding a `pkg` method that exposes pkg-store to your base application. | [homepage](https://github.com/node-base/base-pkg)
* [base](https://www.npmjs.com/package/base): base is the foundation for creating modular, unit testable and highly pluggable node.js applications, starting… [more](https://www.npmjs.com/package/base) | [homepage](https://github.com/node-base/base)

## Contributing

Pull requests and stars are always welcome. For bugs and feature requests, [please create an issue](https://github.com/jonschlinkert/benchmarked/issues/new).

## Building docs

Generate readme and API documentation with [verb](https://github.com/verbose/verb):

```sh
$ npm install verb && npm run docs
```

Or, if [verb](https://github.com/verbose/verb) is installed globally:

```sh
$ verb
```

## Running tests

Install dev dependencies:

```sh
$ npm install -d && npm test
```

## Author

**Jon Schlinkert**

* [github/jonschlinkert](https://github.com/jonschlinkert)
* [twitter/jonschlinkert](http://twitter.com/jonschlinkert)

## License

Copyright © 2016, [Jon Schlinkert](https://github.com/jonschlinkert).
Released under the [MIT license](https://github.com/jonschlinkert/benchmarked/blob/master/LICENSE).

***

_This file was generated by [verb](https://github.com/verbose/verb), v0.9.0, on April 25, 2016._